.. \_overview:

# Overview

cgul is a python package which can be used to ensure consistent data format when working with Xarray
type data objects. It is a lightweight package that works on an xarray-in/xarray-out basis, and is
intended for use with other geo-data packages.
